<template>
  <component :is="layouts[themeConfig.layout]"></component>
</template>

<script setup lang="ts" name="layout">
import { onBeforeMount, onUnmounted, defineAsyncComponent } from 'vue'
import { useThemeConfig } from '/@/stores/themeConfig'
import { storeToRefs } from 'pinia';
import { Local } from '/@/utils/storage';
import mittBus from '/@/utils/mitt';

const storesThemeConfig = useThemeConfig()
const { themeConfig } = storeToRefs(storesThemeConfig)
const layouts: any = {
  defaults: defineAsyncComponent(() => import('/@/layout/main/defaults.vue')),//加载默认布局-->入口默认
  classic: defineAsyncComponent(() => import('/@/layout/main/classic.vue')),//加载经典布局
  transverse: defineAsyncComponent(() => import('/@/layout/main/transverse.vue')),//加载横向布局
  columns: defineAsyncComponent(() => import('/@/layout/main/columns.vue')),//加载分栏布局
};
// 一进入加载组件 窗口大小改变时(适配移动端)
const onLayoutResize = () => {
  if (!Local.get('oldLayout')) Local.set('oldLayout', themeConfig.value.layout) //从缓存获取调用哪个皮肤
  const clientWidth = document.body.clientWidth
  if (clientWidth < 1000) {
    themeConfig.value.isCollapse = false
    mittBus.emit('layoutMobileResize', {//1.发送架构布局样式--》2. src\layout\component\aside.vue--》onBeforeMount 接收监听  --》setings.vue  onMounted  mittBus.on('layoutMobileResize', (res: any) => {initLayoutChangeFun();//接收初始化html布局样式})
      layout: 'defaults',
      clientWidth
    })
  } else {
    mittBus.emit('layoutMobileResize', {
      layout: Local.get('oldLayout') ? Local.get('oldLayout') : themeConfig.value.layout,
      clientWidth
    })
  }
}
//一进入加载组件
onBeforeMount(() => {
  onLayoutResize();//先加载全局架构布局样式
  window.addEventListener('resize', onLayoutResize)
});
onUnmounted(() => {
  window.removeEventListener('resize', onLayoutResize)
});
</script>
<style lang='scss' scoped></style>